@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content.article.maincontainer package
 
-$Id: interfaces.py 49612 2008-01-21 12:55:05Z cray $
+$Id: interfaces.py 49687 2008-01-23 14:35:50Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49612 $"
+__version__ = "$Revision: 49687 $"
 
 from zope.interface import Interface
 
@@ -50,6 +50,8 @@ class IMainContainer(IPossibleSite, IOrderedContainer) :
     
     __setitem__.precondition = ItemTypePrecondition(IMainContent)
 
+class IMainContainerOrdered(IMainContainer) :
+    """ Division Container """
 
 class IUrlDescriptor(Interface) :
     """ Describe URL its title and alternative text
