@@ -2,23 +2,23 @@
 #######################################################################
 """Maincontainer class for the Zope 3 based maincontainer package
 
-$Id: maincontainer.py 49612 2008-01-21 12:55:05Z cray $
+$Id: maincontainer.py 49687 2008-01-23 14:35:50Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49612 $"
+__version__ = "$Revision: 49687 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
 from zope.app.component.site import SiteManagerContainer
 from zope.app.container.ordered import OrderedContainer
-from interfaces import IMainContainer, IMainContained, IUrlPage, IMainPage
+from interfaces import IMainContainerOrdered, IMainContained, IUrlPage, IMainPage
 
 class MainContainer(OrderedContainer, SiteManagerContainer) :
     """ Basic container for future CMS
     """
 
-    implements(IMainContainer, IMainContained, IUrlPage, IMainPage)
+    implements(IMainContainerOrdered, IMainContained, IUrlPage, IMainPage)
 
     urls = ()
 
